@@ -34,9 +34,8 @@ def commit():
     repo = Repo(os.getcwd())
     # print(repo)
     diff = repo.git.diff()
-    # print(diff)
-    # print(repo.git.diff())     
-    resp = requests.post('https://api.litcommit.com/predict/commit', json={"prompt": diff}) 
+    print("OK")
+    resp = requests.post('https://api.litcommit.com/predict/commit', json={"prompt": diff[0:2048]}) 
     # Then commit those
     # print(resp.status_code)
     # resp = resp.json()
